CREATE OR REPLACE PROCEDURE USP_S_PURGE_DOMAIN_WORKITEMS (
	iv_date		IN DATE,
	iv_status	IN NUMBER,
	iv_domainid	IN VARCHAR2,
	RC1 IN OUT SYS_REFCURSOR
)
AS
  LV_CANCELLED_STATUS CONSTANT NUMBER(2) := 12;
  LV_FINISHED_STATUS CONSTANT NUMBER(2) := 2;
BEGIN
--
	DELETE FROM TT_WORKITEM_IDS;
	DELETE FROM TT_PHYSICAL_PATH;
	DELETE FROM TT_DOC_RESOURCE_ID_LIST;
	DELETE FROM TT_ATTACHMENT_ID_LIST;
--
	INSERT INTO TT_WORKITEM_IDS
	SELECT ID FROM OCM_WORK_QUEUE owq
	  LEFT JOIN TDS_REQUESTS tr ON TO_NUMBER(tr.Reference) = owq.ID
	 WHERE owq.STATUS = iv_status
	   AND owq.DATE_ < iv_date
	   AND owq.DOMAIN_NAME = iv_domainid
	   AND (
	   ((iv_status = LV_CANCELLED_STATUS) OR (iv_status = LV_FINISHED_STATUS)) OR
	   tr.REQUESTID IN (
		SELECT r.REQUESTID FROM TDS_REQUESTS r
		  LEFT JOIN TDS_REQUESTCHANNELS rc
		    ON r.REQUESTID = rc.REQUESTID
		 GROUP BY r.REQUESTID
		HAVING COUNT(rc.REQUESTID) = 0));
--
	INSERT INTO TT_DOC_RESOURCE_ID_LIST
	SELECT DOC_RESOURCE_ID FROM OCM_WORK_QUEUE_RESOURCE owqr
	  JOIN TT_WORKITEM_IDS owq ON owqr.WORK_ITEM_ID = owq.ID;
--
	INSERT INTO TT_ATTACHMENT_ID_LIST
	SELECT a.ID FROM ATTACHMENTS a
	  JOIN TT_WORKITEM_IDS owq ON a.OCM_WORK_QUEUE_ID = owq.ID;
--
	INSERT INTO TT_DOC_RESOURCE_ID_LIST
	SELECT a.SOURCE_DOC_RESOURCE_ID FROM ATTACHMENTS a
	  JOIN TT_WORKITEM_IDS owq ON a.OCM_WORK_QUEUE_ID = owq.ID;
--
	INSERT INTO TT_PHYSICAL_PATH
	SELECT PHYSICAL_PATH
	  FROM DOC_STORAGE_LOCATIONS s
	  JOIN DOC_RESOURCES r ON s.FSL_ID = r.FSL_ID
	  JOIN TT_DOC_RESOURCE_ID_LIST i ON r.DOC_RESOURCE_ID = i.DOC_RESOURCE_ID;
--
	INSERT INTO TT_PHYSICAL_PATH
	SELECT PRECOMPOSED_ONH_FILE_PATH
	  FROM CONVERTED_ATTACHMENTS c
	  JOIN TT_ATTACHMENT_ID_LIST a ON c.ATTACHMENT_ID = a.ATTACHMENT_ID
	 WHERE PRECOMPOSED_ONH_FILE_PATH IS NOT NULL;
--
	INSERT INTO TT_PHYSICAL_PATH
	SELECT PRECOMPOSED_METRICS_FILE_PATH
	  FROM CONVERTED_ATTACHMENTS c
	  JOIN TT_ATTACHMENT_ID_LIST a ON c.ATTACHMENT_ID = a.ATTACHMENT_ID
	 WHERE PRECOMPOSED_METRICS_FILE_PATH IS NOT NULL;
--
	DELETE CONVERTED_ATTACHMENTS
	 WHERE EXISTS (SELECT TT_ATTACHMENT_ID_LIST.ATTACHMENT_ID
                     FROM TT_ATTACHMENT_ID_LIST
                    WHERE TT_ATTACHMENT_ID_LIST.ATTACHMENT_ID = CONVERTED_ATTACHMENTS.ATTACHMENT_ID);
--
	DELETE ATTACHMENTS
	 WHERE EXISTS (SELECT TT_ATTACHMENT_ID_LIST.ATTACHMENT_ID
                     FROM TT_ATTACHMENT_ID_LIST
                    WHERE TT_ATTACHMENT_ID_LIST.ATTACHMENT_ID = ATTACHMENTS.ID);
--
	DELETE FROM DOC_VERSIONS
	 WHERE EXISTS (SELECT TT_DOC_RESOURCE_ID_LIST.DOC_RESOURCE_ID
                     FROM TT_DOC_RESOURCE_ID_LIST
                    WHERE TT_DOC_RESOURCE_ID_LIST.DOC_RESOURCE_ID = DOC_VERSIONS.DOC_RESOURCE_ID);
--
	DELETE FROM DOC_FAVORITE
	 WHERE EXISTS (SELECT TT_DOC_RESOURCE_ID_LIST.DOC_RESOURCE_ID
                     FROM TT_DOC_RESOURCE_ID_LIST
                    WHERE TT_DOC_RESOURCE_ID_LIST.DOC_RESOURCE_ID = DOC_FAVORITE.DOC_RESOURCE_ID);
--
	DELETE FROM DOC_MONITORS
	 WHERE EXISTS (SELECT TT_DOC_RESOURCE_ID_LIST.DOC_RESOURCE_ID
                     FROM TT_DOC_RESOURCE_ID_LIST
                    WHERE TT_DOC_RESOURCE_ID_LIST.DOC_RESOURCE_ID = DOC_MONITORS.DOC_RESOURCE_ID);
--
	DELETE FROM DOC_LOGICAL_PATH
	 WHERE EXISTS (SELECT TT_DOC_RESOURCE_ID_LIST.DOC_RESOURCE_ID
                     FROM TT_DOC_RESOURCE_ID_LIST
                    WHERE TT_DOC_RESOURCE_ID_LIST.DOC_RESOURCE_ID = DOC_LOGICAL_PATH.Res_ID);
--
	DELETE FROM DOC_STORAGE_LOCATIONS
	 WHERE EXISTS (SELECT TT_DOC_RESOURCE_ID_LIST.DOC_RESOURCE_ID
                     FROM TT_DOC_RESOURCE_ID_LIST, DOC_Resources
                    WHERE TT_DOC_RESOURCE_ID_LIST.DOC_RESOURCE_ID = DOC_RESOURCES.DOC_RESOURCE_ID
                      AND DOC_RESOURCES.FSL_ID = DOC_STORAGE_LOCATIONS.FSL_ID);
--
	DELETE FROM OCM_WORK_QUEUE_OPERATOR
	 WHERE EXISTS (SELECT TT_WORKITEM_IDS.ID
                     FROM TT_WORKITEM_IDS
                    WHERE TT_WORKITEM_IDS.ID = OCM_WORK_QUEUE_OPERATOR.OCM_WORK_QUEUE_ID);
--
	DELETE FROM OCM_WORK_QUEUE_RESOURCE
	 WHERE EXISTS (SELECT TT_WORKITEM_IDS.ID
                     FROM TT_WORKITEM_IDS
                    WHERE TT_WORKITEM_IDS.ID = OCM_WORK_QUEUE_RESOURCE.WORK_ITEM_ID);
--
	DELETE FROM OCM_WORK_QUEUE
	 WHERE EXISTS (SELECT TT_WORKITEM_IDS.ID
                     FROM TT_WORKITEM_IDS
                    WHERE TT_WORKITEM_IDS.ID = OCM_Work_Queue.ID);
--
	DELETE FROM DOC_AUDITS
	 WHERE ACTION_DATE < iv_date
	   AND DOMAIN_ID = iv_domainid;
--
	DELETE FROM DOC_RESOURCES
	 WHERE EXISTS (SELECT TT_DOC_RESOURCE_ID_LIST.DOC_RESOURCE_ID
                     FROM TT_DOC_RESOURCE_ID_LIST
                    WHERE TT_DOC_RESOURCE_ID_LIST.DOC_RESOURCE_ID = DOC_RESOURCES.DOC_RESOURCE_ID);
--
	OPEN RC1 FOR SELECT PHYSICAL_PATH FROM TT_PHYSICAL_PATH;
--
END;
/